/*
 * Copyright (C) 2004  Heinz Mauelshagen, Red Hat GmbH. All rights reserved.
 *
 * See file LICENSE at the top of this source tree for license information.
 */

#ifndef _DMRAID_H_
#define _DMRAID_H_

#include <stdint.h>
#include <sys/types.h>
#include "misc/lib_context.h"
#include "display/display.h"
#include "format/format.h"
#include "log/log.h"

/*
 * Library init/exit
 */
int libdmraid_init(struct lib_context **lc, int argc, char **argv);
void libdmraid_exit(struct lib_context *lc);
struct lib_context *alloc_lib_context(char **argv);

/*
 * Retrieve version identifiers.
 */
int dm_version(struct lib_context *lc, char *version, size_t size);
const char *libdmraid_version(struct lib_context *lc);

/*
 * Dealing with formats.
 */
int check_valid_format(struct lib_context *lc, char *fmt);

/*
 * Dealing with devices.
 */
unsigned int count_devices(struct lib_context *lc, enum dev_type type);
int discover_devices(struct lib_context *lc);
void discover_raid_devices(struct lib_context *lc, char **fmt_names, char **devices);
void discover_partitions(struct lib_context *lc);
void free_disk_info(struct lib_context *lc, void *di);

/*
 * Erase ondisk metadata.
 */
int erase_metadata(struct lib_context *lc);

/*
 * Dealing with RAID sets.
 */
const char *get_set_type(struct lib_context *lc, void *rs);
const char *get_set_name(struct lib_context *lc, void *rs);
int group_set(struct lib_context *lc, char *name);
void process_sets(int (*func)(struct lib_context *l, void *v, int a),
		  struct lib_context *lc, int arg, int partitions);
int activate_set(struct lib_context *lc, void *rs);
int deactivate_set(struct lib_context *lc, void *rs);

/*
 * Memory allocation
 */
void dbg_free(void *ptr);
void *dbg_malloc(size_t size);
void *dbg_realloc(void *ptr, size_t size);
void *dbg_strdup(void *ptr);

#endif
