/*
 * Copyright (C) 2004  Heinz Mauelshagen, Red Hat GmbH. All rights reserved.
 *
 * See file LICENSE at the top of this source tree for license information.
 */

/* Cheers utils.h */

#ifndef _BYTEORDER_H
#define _BYTEORDER_H

static inline int32_t swap32(int32_t x)
{
	return((((u_int32_t)x & 0x000000ffU) << 24) | 
	       (((u_int32_t)x & 0x0000ff00U) <<  8) | 
	       (((u_int32_t)x & 0x00ff0000U) >>  8) | 
	       (((u_int32_t)x & 0xff000000U) >> 24));
}

static inline int16_t swap16(int16_t x)
{
	return((((u_int16_t)x & 0x00ffU) << 8) | 
	       (((u_int16_t)x & 0xff00U) >> 8));
}

#if BYTE_ORDER == LITTLE_ENDIAN

static inline int32_t be32_to_cpu(int32_t x)
{
	return(swap32(x));
}

static inline int16_t be16_to_cpu(int16_t x)
{
	return(swap16(x));
}

static inline int32_t le32_to_cpu(int32_t x)
{
	return(x);
}

static inline int16_t le16_to_cpu(int16_t x)
{
	return(x);
}

#else

static inline int32_t be32_to_cpu(int32_t x)
{
	return(x);
}

static inline int16_t be16_to_cpu(int16_t x)
{
	return(x);
}

static inline int32_t le32_to_cpu(int32_t x)
{
	return(swap32(x));
}

static inline int16_t le16_to_cpu(int16_t x)
{
	return(swap16(x));
}

#endif /* #if BYTE_ORDER == LITTLE_ENDIAN */

static inline int32_t cpu_to_be32(int32_t x)
{
	return(be32_to_cpu(x));
}

static inline int32_t cpu_to_le32(int32_t x)
{
	return(le32_to_cpu(x));
}

static inline int16_t cpu_to_be16(int16_t x)
{
	return(be16_to_cpu(x));
}

static inline int16_t cpu_to_le16(int16_t x)
{
	return(le16_to_cpu(x));
}

#endif
